/* $Id: ibuf_stdin.c 616 2005-08-19 20:11:01Z bruce $ */
#include <unistd.h>
#include "ibuf.h"

static char buffer[4096];

/** Input buffer for \c stdin */
ibuf inbuf = { { 0, buffer, 4096, 0, 0, 0, 0, IOBUF_NEEDSCLOSE, 0 },
	       0, (ibuf_fn)read };
